#
# spec file for package ghc-hpio
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hpio
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.9.0.6
Release:        4.3
Summary:        Monads for GPIO in Haskell
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-protolude-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-bytestring-devel
BuildRequires:  ghc-unix-devel
%if %{with tests}
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
This package provides an embedded DSL for writing cross-platform GPIO programs
in Haskell. Currently only Linux is supported (via the 'sysfs' filesystem), but
other Unix GPIO platforms will be supported in the future.

Monads and low-level actions are also provided for each supported platform's
native GPIO API, if you want to program directly to the platform API.

Example programs are provided in the 'examples' directory of the source code
distribution. There is also a "System.GPIO.Tutorial" module, which explains how
to use the cross-platform DSL.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/hpio-example
%{_bindir}/hpio-reader-example
%{_bindir}/hpio-sysfs-example

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%changelog
* Thu Apr 12 2018 psimons@suse.com
- Update hpio to version 0.9.0.6.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri Jun 30 2017 psimons@suse.com
- Update to version 0.8.0.10.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.8.0.9.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 0.8.0.7 with cabal2obs.
* Mon Jan 30 2017 psimons@suse.com
- Update to version 0.8.0.6 with cabal2obs.
* Wed Jan 18 2017 psimons@suse.com
- Update to version 0.8.0.5 with cabal2obs.
* Sun Oct 30 2016 psimons@suse.com
- Update to version 0.8.0.4 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.8.0.3 revision 0 with cabal2obs.
